@@ -13,7 +13,6 @@
 from keystoneauth1.exceptions import base as kae_base
 from keystoneauth1.exceptions import http as kae_http
 from openstack import exceptions as sdkexc
-
 from oslo_serialization import jsonutils
 from requests import exceptions as reqexc
 import six
@@ -230,19 +229,40 @@ _EXCEPTION_MAP = {
 def parse_exception(exc):
     """Parse exception code and yield useful information.
 
-    :param details: details of the exception.
+    :param exc: details of the exception.
     """
     if isinstance(exc, sdkexc.HttpException):
-        try:
-            record = jsonutils.loads(exc.details)
-        except Exception:
-            # If the exc.details is not in JSON format
-            record = {
-                'error': {
-                    'code': exc.status_code,
-                    'message': exc.details,
+        if exc.details is None:
+            data = exc.response.json()
+            code = data.get('code', None)
+            message = data.get('message', None)
+            error = data.get('error', None)
+            if error:
+                record = {
+                    'error': {
+                        'code': exc.http_status,
+                        'message': message or exc.message
+                    }
+                }
+            else:
+                info = data.values()[0]
+                record = {
+                    'error': {
+                        'code': info.get('code', code),
+                        'message': info.get('message', message)
+                    }
+                }
+        else:
+            try:
+                record = jsonutils.loads(exc.details)
+            except Exception:
+                # If the exc.details is not in JSON format
+                record = {
+                    'error': {
+                        'code': exc.http_status,
+                        'message': exc,
+                    }
                 }
-            }
     elif isinstance(exc, reqexc.RequestException):
         # Exceptions that are not captured by SDK
         record = {
